@@ -20,9 +20,10 @@ def main(
             "Cluster Size",
             "MCD",
             "Connectivity",
+            "Cut Size",
         ])}
     df = df.select(
-        sorted(df.columns, key=lambda c: ord[c])
+        sorted(df.columns, key=lambda c: ord.get(c, 99))
     )
     print(
         df.to_pandas().to_latex(
